@@ -6,6 +6,11 @@
 #' function, containing values for the 'x', 'y' and 'z' coordinates as columns (labeled as such)
 #' @param size size of the points in the plot (defaults to 0.02)
 #' @param col color of the points in the plot (defaults to black)
+#' @param vertexsize size of the points at the vertices
+#' @param achrosize size of the point in the achromatic center
+#' @param achrocol color of the point in the achromatic center
+#' @param lwd line width for the edges of the tetrahedron
+#' @param lcol line color for the edges of the tetrahedron
 #' @param new should a new 3D plot be called (defaults to \code{FALSE})?
 #' @param hspin if \code{TRUE}, the graphic will spin horizontally (around the 'z' axis)(defaults to \code{FALSE}).
 #' @param vspin if \code{TRUE}, the graphic will spin vertically (around the 'x' axis)(defaults to \code{FALSE}).
@@ -52,7 +57,9 @@
 
 #ToDo: Add option to not plot tetrahedron
 
-tcsplot<- function(tcsdata, size=0.02, col='black', new=FALSE, hspin=FALSE, 
+tcsplot<- function(tcsdata, size=0.02, col='black', 
+                  vertexsize=0.02, achrosize=0.01, achrocol='grey', 
+                  lwd=1, lcol='lightgrey', new=FALSE, hspin=FALSE, 
                   vspin=FALSE, floor=TRUE, grid=TRUE, fill=TRUE) {
 
 # if(class(tcsdata)=='tcs'){
@@ -76,19 +83,25 @@ cl=t(col2rgb('#E41A1C'))/255
 plot3d(unlist(ttv[c('xu','xs','xm','xl')]),
 		unlist(ttv[c('yu','ys','ym','yl')]),
 		unlist(ttv[c('zu','zs','zm','zl')]), type='s', lit=F,
-		radius=0.02, box=F, axes=F, xlab='',ylab='',zlab='',
+		radius=vertexsize, box=F, axes=F, xlab='',ylab='',zlab='',
 		col=c(rgb(cu[1],cu[2],cu[3]), rgb(cs[1],cs[2],cs[3]), 
 		rgb(cm[1],cm[2],cm[3]), rgb(cl[1],cl[2],cl[3])))
 
 
-segments3d(ttv[c('xu','xs')], ttv[c('yu','ys')], ttv[c('zu','zs')], color='lightgrey')
-segments3d(ttv[c('xu','xm')], ttv[c('yu','ym')], ttv[c('zu','zm')], color='lightgrey')
-segments3d(ttv[c('xu','xl')], ttv[c('yu','yl')], ttv[c('zu','zl')], color='lightgrey')
-segments3d(ttv[c('xs','xm')], ttv[c('ys','ym')], ttv[c('zs','zm')], color='lightgrey')
-segments3d(ttv[c('xs','xl')], ttv[c('ys','yl')], ttv[c('zs','zl')], color='lightgrey')
-segments3d(ttv[c('xl','xm')], ttv[c('yl','ym')], ttv[c('zl','zm')], color='lightgrey')
+segments3d(ttv[c('xu','xs')], ttv[c('yu','ys')], ttv[c('zu','zs')], 
+  color=lcol, lwd=lwd)
+segments3d(ttv[c('xu','xm')], ttv[c('yu','ym')], ttv[c('zu','zm')], 
+  color=lcol, lwd=lwd)
+segments3d(ttv[c('xu','xl')], ttv[c('yu','yl')], ttv[c('zu','zl')], 
+  color=lcol, lwd=lwd)
+segments3d(ttv[c('xs','xm')], ttv[c('ys','ym')], ttv[c('zs','zm')], 
+  color=lcol, lwd=lwd)
+segments3d(ttv[c('xs','xl')], ttv[c('ys','yl')], ttv[c('zs','zl')], 
+  color=lcol, lwd=lwd)
+segments3d(ttv[c('xl','xm')], ttv[c('yl','ym')], ttv[c('zl','zm')], 
+  color=lcol, lwd=lwd)
 
-spheres3d(0,0,0,col='grey', radius=0.01, lit=F)
+spheres3d(0,0,0, col= achrocol, radius=achrosize, lit=F)
 
 spheres3d(tcsdata[,c('x','y','z')], radius=size, color=col, lit=F)
 
